@@ -14,7 +14,9 @@ aictab.glm <-
     Results$Delta_AICc<-Results$AICc-min(Results$AICc)            #compute delta AICc
     Results$ModelLik<-exp(-0.5*Results$Delta_AICc)                #compute model likelihood required to compute Akaike weights
     Results$AICcWt<-Results$ModelLik/sum(Results$ModelLik)        #compute Akaike weights
-    
+
+    ##check if some models are redundant
+    if(length(unique(Results$AICc)) != length(cand.set)) warning("\nCheck model structure carefully as some models may be redundant\n")
          
     ##check if AICc and c.hat = 1
     if(second.ord==TRUE && c.hat == 1) {
